.. _spkg_soupsieve:

soupsieve: Modern CSS selector implementation for Beautiful Soup
================================================================

Description
-----------

Modern CSS selector implementation for Beautiful Soup

License
-------

Upstream Contact
----------------

https://pypi.org/project/soupsieve/



Type
----

standard


Dependencies
------------

- $(PYTHON)
- :ref:`spkg_pip`

Version Information
-------------------

package-version.txt::

    2.5

version_requirements.txt::

    soupsieve

Installation commands
---------------------

.. tab:: PyPI:

   .. CODE-BLOCK:: bash

       $ pip install soupsieve

.. tab:: Sage distribution:

   .. CODE-BLOCK:: bash

       $ sage -i soupsieve

.. tab:: conda-forge:

   .. CODE-BLOCK:: bash

       $ conda install soupsieve

.. tab:: Fedora/Redhat/CentOS:

   .. CODE-BLOCK:: bash

       $ sudo dnf install python3-soupsieve


If the system package is installed and if the (experimental) option
``--enable-system-site-packages`` is passed to ``./configure``, then 
``./configure`` will check if the system package can be used.
